pyxmpp.interfaces

Package pyxmpp :: Module interfaces |
[hide private]

# Module interfaces

source code

Interfaces for flexible API extensions.

Variables | [hide private]
| __revision__ = ``'``$Id: error.py 647 2006-08-26 18:27:39Z jajcus $``'``
| Interface = `<InterfaceClass pyxmpp.inteface_micro_impl.Interface>`
| IPyXMPPHelper = `<InterfaceClass pyxmpp.interfaces.IPyXMPPHelper>`
| IPresenceHandlersProvider = `<InterfaceClass pyxmpp.interfaces.`...``
| IMessageHandlersProvider = `<InterfaceClass pyxmpp.interfaces.I`...``
| IIqHandlersProvider = `<InterfaceClass pyxmpp.interfaces.IIqHan`...``
| IStanzaHandlersProvider = `<InterfaceClass pyxmpp.interfaces.IS`...``
| IFeaturesProvider = `<InterfaceClass pyxmpp.interfaces.IFeature`...``
| __package__ = ``'``pyxmpp``'``
| name = ``'``__revision__``'``

Imports: Attribute

Variables Details | [hide private]

  ### IPresenceHandlersProvider Value:
      <InterfaceClass pyxmpp.interfaces.IPresenceHandlersProvider>

  ### IMessageHandlersProvider Value:
      <InterfaceClass pyxmpp.interfaces.IMessageHandlersProvider>

  ### IIqHandlersProvider Value:
      <InterfaceClass pyxmpp.interfaces.IIqHandlersProvider>

  ### IStanzaHandlersProvider Value:
      <InterfaceClass pyxmpp.interfaces.IStanzaHandlersProvider>

  ### IFeaturesProvider Value:
      <InterfaceClass pyxmpp.interfaces.IFeaturesProvider>